===============================
Published work with lenstronomy
===============================

In this section you can find the concept papers **lenstronomy** is based on the list of science publications that made
use of **lenstronomy**. Please let the developers know when you publish a paper that made use of **lenstronomy**.
We are happy to include your publication in this list.



Core lenstronomy methodology and software publications
------------------------------------------------------

* lenstronomy: Multi-purpose gravitational lens modelling software package; `Birrer & Amara 2018 <https://ui.adsabs.harvard.edu/abs/2018PDU....22..189B>`_
    *This is the lenstronomy software paper. Please cite this paper whenever you make use of lenstronomy. The paper gives a design overview and gives some use cases.*

* Gravitational Lens Modeling with Basis Sets; `Birrer et al. 2015 <http://adsabs.harvard.edu/abs/2015ApJ...813..102B>`_
    *This is the method paper lenstronomy is primary based on. Please cite this paper whenever you publish results with lenstronomy by using Shapelet basis sets and/or the PSO and MCMC chain.*


Measuring the Hubble constant
-----------------------------

* The mass-sheet degeneracy and time-delay cosmography: analysis of the strong lens RXJ1131-1231; `Birrer et al. 2016 <http://adsabs.harvard.edu/abs/2016JCAP...08..020B>`_
    *This paper performs a cosmographic analysis and applies the Shapelet basis set scaling to marginalize over a major lensing degeneracy.*

* H0LiCOW - IX. Cosmographic analysis of the doubly imaged quasar SDSS 1206+4332 and a new measurement of the Hubble constant; `Birrer et al. 2019 <https://ui.adsabs.harvard.edu/#abs/2018arXiv180901274B/abstract>`_
    *This paper performs a cosmographic analysis with power-law and composite models and covers a range in complexity in the source reconstruction*

* Astrometric requirements for strong lensing time-delay cosmography; `Birrer & Treu 2019 <https://ui.adsabs.harvard.edu/abs/2019MNRAS.tmp.2172B>`_
    *Derives requirements on how well the image positions of time-variable sources has to be known to perform a time-delay cosmographic measurement*

* H0LiCOW XIII. A 2.4% measurement of  H0 from lensed quasars: 5.3σ tension between early and late-Universe probes; `Wong et al. 2019 <https://ui.adsabs.harvard.edu/abs/2019arXiv190704869W>`_
    *Joint analysis of the six H0LiCOW lenses including the lenstronomy analysis of J1206*

* STRIDES: A 3.9 per cent measurement of the Hubble constant from the strongly lensed system DES J0408-5354; `Shajib et al. 2019 <https://ui.adsabs.harvard.edu/abs/2019arXiv191006306S/abstract>`_
    *most precise single lensing constraint on the Hubble constant. This analysis includes two source planes and three lensing planes*

* TDCOSMO. I. An exploration of systematic uncertainties in the inference of H0 from time-delay cosmography `Millon et al. 2020 <https://ui.adsabs.harvard.edu/abs/2019arXiv191208027M/abstract>`_
    *mock lenses to test accuracy on the recovered H0 value*

* Lens modelling of the strongly lensed Type Ia supernova iPTF16geu `Moertsell et al. 2020 <https://ui.adsabs.harvard.edu/abs/2019arXiv190706609M/abstract>`_
    *Modeling of a lensed supernova to measure the Hubble constant*

* The impact of line-of-sight structures on measuring H0 with strong lensing time-delays `Li, Becker and Dye 2020 <https://arxiv.org/abs/2006.08540v1>`_
    *Point source position and time-delay modeling of quads*




Dark Matter substructure
------------------------

* Lensing substructure quantification in RXJ1131-1231: a 2 keV lower bound on dark matter thermal relic mass; `Birrer et al. 2017b <http://adsabs.harvard.edu/abs/2017JCAP...05..037B>`_
    *This paper quantifies the substructure content of a lens by a sub-clump scanning procedure and the application of Approximate Bayesian Computing.*

* Probing the nature of dark matter by forward modelling flux ratios in strong gravitational lenses; `Gilman et al. 2018 <https://ui.adsabs.harvard.edu/abs/2018MNRAS.481..819G>`_
    * *

* Probing dark matter structure down to 10**7 solar masses: flux ratio statistics in gravitational lenses with line-of-sight haloes; `Gilman et al. 2019a <https://ui.adsabs.harvard.edu/abs/2019MNRAS.487.5721G>`_
    * *

* Double dark matter vision: twice the number of compact-source lenses with narrow-line lensing and the WFC3 Grism; `Nierenberg et al. 2019 <https://ui.adsabs.harvard.edu/abs/2019arXiv190806344N>`_
    * *

* Warm dark matter chills out: constraints on the halo mass function and the free-streaming length of dark matter with 8 quadruple-image strong gravitational lenses; `Gilman et al. 2019b <https://ui.adsabs.harvard.edu/abs/2019arXiv190806983G>`_
    * *

* Constraints on the mass-concentration relation of cold dark matter halos with 11 strong gravitational lenses; `Gilman et al. 2019c <https://ui.adsabs.harvard.edu/abs/2019arXiv190902573G>`_
    * *

* Circumventing Lens Modeling to Detect Dark Matter Substructure in Strong Lens Images with Convolutional Neural Networks; `Diaz Rivero & Dvorkin <https://ui.adsabs.harvard.edu/abs/2019arXiv191000015D>`_
    * *

* Dark Matter Subhalos, Strong Lensing and Machine Learning; `Varma, Fairbairn, Figueroa <https://arxiv.org/abs/2005.05353>`_
    * *


* Quantifying the Line-of-Sight Halo Contribution to the Dark Matter Convergence Power Spectrum from Strong Gravitational Lenses; `Sengul et a. 2020 <https://arxiv.org/abs/2006.07383>`_
    * *


Automatized Lens Modeling
-------------------------

* Is every strong lens model unhappy in its own way? Uniform modelling of a sample of 12 quadruply+ imaged quasars; `Shajib et al. 2018 <https://ui.adsabs.harvard.edu/abs/2019MNRAS.483.5649S>`_
    *This work presents a uniform modelling framework to model 13 quadruply lensed quasars in three HST bands.*


Quasar-host galaxy decomposition
--------------------------------

* The mass relations between supermassive black holes and their host galaxies at 1<z<2 with HST-WFC3; `Ding et al. 2019 <https://arxiv.org/abs/1910.11875>`_
    *Quasar host galaxy decomposition at high redshift on HST imaging and marginalization over PSF uncertainties.*

* Testing the Evolution of the Correlations between Supermassive Black Holes and their Host Galaxies using Eight Strongly Lensed Quasars; `Ding et al. 2020 <https://ui.adsabs.harvard.edu/abs/2020arXiv200513550D/abstract>`_
    *Quasar host galaxy decomposition with lensed quasars.*



Theory papers
-------------

* Line-of-sight effects in strong lensing: putting theory into practice; `Birrer et al. 2017a <http://adsabs.harvard.edu/abs/2017JCAP...04..049B>`_
    *This paper formulates an effective parameterization of line-of-sight structure for strong gravitational lens modelling and applies this technique to an Einstein ring in the COSMOS field*

* Cosmic Shear with Einstein Rings; `Birrer et al. 2018a <http://adsabs.harvard.edu/abs/2018ApJ...852L..14B>`_
    *Forecast paper to measure cosmic shear with Einstein ring lenses. The forecast is made based on lenstronomy simulations.*

* Unified lensing and kinematic analysis for any elliptical mass profile; `Shajib 2019 <https://ui.adsabs.harvard.edu/abs/2019MNRAS.488.1387S>`_
    *Provides a methodology to generalize the multi-Gaussian expansion to general elliptical mass and light profiles*
